==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridSizeChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSizeChangedEventArgsDescription } from "./GridSizeChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSizeChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSizeChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSizeChangedEventArgsDescriptionMetadata.a == null) {
                GridSizeChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSizeChangedEventArgsDescriptionMetadata.c(GridSizeChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(GridSizeChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridSizeChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Width", "Number:double");
            a.item("Height", "Number:double");
        }
        static d(a) {
            GridSizeChangedEventArgsDescriptionMetadata.b(a);
            a.aa("GridSizeChangedEventArgs", () => new GridSizeChangedEventArgsDescription());
            a.z("GridSizeChangedEventArgs", GridSizeChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSizeChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSizeChangedEventArgsDescriptionMetadata, 'GridSizeChangedEventArgsDescriptionMetadata');
    GridSizeChangedEventArgsDescriptionMetadata.a = null;
    return GridSizeChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridSizeChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSizeChangedEventArgsDescription } from "./GridSizeChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSizeChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSizeChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSizeChangedEventArgsDescriptionMetadata.a == null) {
                GridSizeChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSizeChangedEventArgsDescriptionMetadata.c(GridSizeChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridSizeChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridSizeChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Width", "Number:double");
            a.item("Height", "Number:double");
        }
        static d(a) {
            GridSizeChangedEventArgsDescriptionMetadata.b(a);
            a.ac("GridSizeChangedEventArgs", () => new GridSizeChangedEventArgsDescription());
            a.ab("GridSizeChangedEventArgs", GridSizeChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSizeChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSizeChangedEventArgsDescriptionMetadata, 'GridSizeChangedEventArgsDescriptionMetadata');
    GridSizeChangedEventArgsDescriptionMetadata.a = null;
    return GridSizeChangedEventArgsDescriptionMetadata;
})();
